@@ -10,18 +10,41 @@ from contextlib import suppress
 from pickle import dump, load
 from pkg_resources import resource_string as resource_bytes
 from ubuntu_image.builder import ModelAssertionBuilder
+from ubuntu_image.helpers import as_size
 from ubuntu_image.i18n import _
 
 
 _logger = logging.getLogger('ubuntu-image')
-try:
-    __version__ = resource_bytes('ubuntu_image', 'version.txt').decode('utf-8')
-except FileNotFoundError:                           # pragma: nocover
-    # Probably, setup.py hasn't been run yet to generate the version.txt.
-    __version__ = 'dev'
+
+# Try to get the version number, which will be different if we're living in a
+# snap world or a deb.  Actually, I'd prefer to not even have the -NubuntuY
+# version string when we're running from source, but that's trickier, so don't
+# worry about it.
+__version__ = os.environ.get('SNAP_VERSION')
+if __version__ is None:                                      # pragma: nocover
+    try:
+        __version__ = resource_bytes(
+            'ubuntu_image', 'version.txt').decode('utf-8')
+    except FileNotFoundError:
+        # Probably, setup.py hasn't been run yet to generate the version.txt.
+        __version__ = 'dev'
+
+
 PROGRAM = 'ubuntu-image'
 
 
+class SizeAction(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        try:
+            size = as_size(values)
+        except (KeyError, ValueError):
+            raise argparse.ArgumentError(
+                self, 'Invalid size: {}'.format(values))
+        setattr(namespace, self.dest, size)
+        # For display purposes.
+        namespace.given_image_size = values
+
+
 def parseargs(argv=None):
     parser = argparse.ArgumentParser(
         prog=PROGRAM,
@@ -47,6 +70,14 @@ def parseargs(argv=None):
         help=_("""The generated disk image file.  If not given, the image will
         be put in a file called disk.img in the working directory (in which
         case, you probably want to specify -w)."""))
+    common_group.add_argument(
+        '--image-size',
+        default=None, action=SizeAction, metavar='SIZE',
+        help=_("""The size of the generated disk image file (see
+        -o/--output).  If this size is smaller than the minimum calculated
+        size of the image a warning will be issued and --image-size will be
+        ignored.  The value is the size in bytes, with allowable suffixes 'M'
+        for MiB and 'G' for GiB."""))
     # Snap-based image options.
     snap_group = parser.add_argument_group(
         _('Image contents options'),
