@@ -110,6 +110,8 @@ class ModelAssertionBuilder(State):
     def load_gadget_yaml(self):
         yaml_file = os.path.join(
             self.unpackdir, 'gadget', 'meta', 'gadget.yaml')
+        # Preserve the gadget.yaml in the working dir.
+        shutil.copy(yaml_file, self.workdir)
         with open(yaml_file, 'r', encoding='utf-8') as fp:
             self.gadget = parse_yaml(fp)
         self._next.append(self.populate_rootfs_contents)
@@ -117,14 +119,21 @@ class ModelAssertionBuilder(State):
     def populate_rootfs_contents(self):
         src = os.path.join(self.unpackdir, 'image')
         dst = os.path.join(self.rootfs, 'system-data')
-        shutil.move(os.path.join(src, 'var'), os.path.join(dst, 'var'))
-        seed_dir = os.path.join(dst, 'var', 'lib', 'cloud', 'seed')
-        cloud_dir = os.path.join(seed_dir, 'nocloud-net')
-        os.makedirs(cloud_dir, exist_ok=True)
-        metadata_file = os.path.join(cloud_dir, 'meta-data')
-        with open(metadata_file, 'w', encoding='utf-8') as fp:
-            print('instance-id: nocloud-static', file=fp)
+        for subdir in os.listdir(src):
+            # LP: #1632134 - copy everything under the image directory except
+            # /boot which goos to the boot partition.
+            if subdir != 'boot':
+                shutil.move(os.path.join(src, subdir),
+                            os.path.join(dst, subdir))
         if self.cloud_init is not None:
+            # LP: #1633232 - Only write out meta-data when the --cloud-init
+            # parameter is given.
+            seed_dir = os.path.join(dst, 'var', 'lib', 'cloud', 'seed')
+            cloud_dir = os.path.join(seed_dir, 'nocloud-net')
+            os.makedirs(cloud_dir, exist_ok=True)
+            metadata_file = os.path.join(cloud_dir, 'meta-data')
+            with open(metadata_file, 'w', encoding='utf-8') as fp:
+                print('instance-id: nocloud-static', file=fp)
             userdata_file = os.path.join(cloud_dir, 'user-data')
             shutil.copy(self.cloud_init, userdata_file)
         # This is just a mount point.
@@ -279,8 +288,17 @@ class ModelAssertionBuilder(State):
         #
         # XXX: Hard-codes last 34 512-byte sectors for backup GPT,
         # empirically derived from sgdisk behavior.
-        self.image_size = ceil((self.rootfs_size + next_avail) /
-                               1024 + 17) * 1024
+        calculated = ceil((self.rootfs_size + next_avail) / 1024 + 17) * 1024
+        if self.args.image_size is None:
+            self.image_size = calculated
+        else:
+            if self.args.image_size < calculated:
+                _logger.warning('Ignoring --image-size={} smaller '
+                                'than minimum required size {}'.format(
+                                    self.args.given_image_size, calculated))
+                self.image_size = calculated
+            else:
+                self.image_size = self.args.image_size
         self.root_img = os.path.join(self.images, 'root.img')
         # Create empty file with holes.
         with open(self.root_img,  'w'):
@@ -356,6 +374,7 @@ class ModelAssertionBuilder(State):
         structures = sorted(volume.structures, key=attrgetter('offset'))
         offset_writes = []
         part_offsets = {}
+        next_offset = 1
         for i, part in enumerate(structures):
             if part.name is not None:
                 part_offsets[part.name] = part.offset
@@ -388,7 +407,7 @@ class ModelAssertionBuilder(State):
         # Create main snappy writable partition as the last partition.
         image.partition(
             part_id,
-            new='{}M:+{}K'.format(next_offset, self.rootfs_size // 1024),
+            new='{}M:+{}K'.format(next_offset, ceil(self.rootfs_size / 1024)),
             typecode=('83', '0FC63DAF-8483-4772-8E79-3D69D8477DE4'))
         if volume.schema is VolumeSchema.gpt:
             image.partition(part_id, change_name='writable')
