@@ -110,7 +110,7 @@ def run(command, *, check=True, **args):
         universal_newlines=True,
         **args)
     if check and proc.returncode != 0:
-        sys.__stderr__.write('COMMAND FAILED: {}'.format(command))
+        sys.__stderr__.write('COMMAND FAILED: {}\n'.format(command))
         # Use the real stdout and stderr; the obvious attributes might be
         # mocked out.
         if proc.stdout is not None:
@@ -169,8 +169,7 @@ def mkfs_ext4(img_file, contents_dir, label='writable'):
     if proc.returncode == 0:
         # We have a new enough e2fsprogs, so we're done.
         return
-    run('mkfs.ext4 -L -T default -O uninit_bg {} {}'.format(
-        label, img_file))
+    run('mkfs.ext4 -L {} -T default -O uninit_bg {}'.format(label, img_file))
     # Only do this if the directory is non-empty.
     if not os.listdir(contents_dir):
         return
